;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "blamer" "20251001.620"
  "Show git blame info about current line."
  '((emacs    "27.1")
    (posframe "1.1.7")
    (async    "1.9.8"))
  :url "https://github.com/artawower/blamer.el"
  :commit "aa9b22d4e847d15a5c4659c0407aa8bf4242cc94"
  :revdesc "aa9b22d4e847"
  :authors '(("Artur Yaroshenko" . "artawower@protonmail.com"))
  :maintainers '(("Artur Yaroshenko" . "artawower@protonmail.com")))
